#
# spec file for package maven-dependency-tree
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           maven-dependency-tree
Version:        3.2.1
Release:        1.4
Summary:        Maven dependency tree artifact
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://maven.apache.org/
Source0:        https://archive.apache.org/dist/maven/shared/%{name}-%{version}-source-release.zip
Source1:        %{name}-build.xml
BuildRequires:  ant
BuildRequires:  atinject
BuildRequires:  fdupes
BuildRequires:  javapackages-local >= 6
BuildRequires:  maven-lib
BuildRequires:  maven-resolver-api
BuildRequires:  maven-resolver-util
BuildRequires:  sisu-inject
BuildRequires:  unzip
BuildArch:      noarch

%description
Apache Maven dependency tree artifact. Originally part of maven-shared.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
This package contains javadoc for %{name}.

%prep
%setup -q
cp %{SOURCE1} build.xml

%build
mkdir -p lib
build-jar-repository -s lib \
  atinject \
  maven/maven-artifact \
  maven/maven-core \
  maven/maven-model \
  maven-resolver/maven-resolver-api \
  maven-resolver/maven-resolver-util \
  org.eclipse.sisu.inject \
  slf4j/api

%{ant} \
  -Dtest.skip=true \
  jar javadoc

%install
# jar
install -dm 0755 %{buildroot}%{_javadir}/%{name}
install -pm 0644 target/%{name}-%{version}.jar %{buildroot}%{_javadir}/%{name}/%{name}.jar
# pom
install -dm 0755 %{buildroot}%{_mavenpomdir}/%{name}
%{mvn_install_pom} pom.xml %{buildroot}%{_mavenpomdir}/%{name}/%{name}.pom
%add_maven_depmap %{name}/%{name}.pom %{name}/%{name}.jar
# javadoc
install -dm 0755 %{buildroot}%{_javadocdir}/%{name}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}/
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE NOTICE

%files javadoc
%{_javadocdir}/%{name}
%license LICENSE NOTICE

%changelog
* Wed Sep 27 2023 Fridrich Strba <fstrba@suse.com>
- Update to version 3.2.1
  * Bug
    + MSHARED-994:  DependencyCollectorBuilder does not collect
    dependencies when artifact has 'war' packaging
    + MSHARED-1016:  Transitive provided dependencies are not
    removed from collected dependency graph
  * New Feature
    + MSHARED-1158:  DependencyCollectorBuilder more configurable
  * Improvement
    + MSHARED-339:  DependencyGraphBuilder does not provide verbose
    tree
    + MSHARED-491:  DependencyGraphBuilders shouldn't need
    reactorProjects for resolving dependencies
    + MSHARED-519:  Maven31DependencyGraphBuilder (and others?)
    should not download dependencies other than the pom
    + MSHARED-657:  plexus-component-annotation in line with
    plexus-component-metadata
    + MSHARED-691:  Upgrade parent to 31
    + MSHARED-788:  Add functionality to collect raw dependencies
    in Maven 3+
    + MSHARED-816:  Annotate DependencyNodes with dependency
    management metadata
    + MSHARED-825:  Require Java 8
    + MSHARED-850:  Upgrade org.eclipse.aether:aether-util
    dependency in org.apache.maven.shared:maven-dependency-tree
    + MSHARED-852:  Add Exclusions to DependencyNode
    + MSHARED-853:  make build Reproducible
    + MSHARED-1070:  Migrate plexus component to JSR-330
    + MSHARED-1071:  Drop maven 3.0 compatibility
  * Dependency upgrade
    + MSHARED-771:  Upgrade shared-component to version 33
    + MSHARED-1069:  Upgrade Parent to 36
    + MSHARED-1114:  Bump maven-shared-components from 36 to 37
* Wed Sep  6 2023 Fridrich Strba <fstrba@suse.com>
- Remove unnecessary dependency on xmvn tools and parent pom
* Sun Mar 20 2022 Fridrich Strba <fstrba@suse.com>
- Build with java source and target levels 8
* Tue May 11 2021 Fridrich Strba <fstrba@suse.com>
- Do not build against the legacy guava20 any more
* Mon Jan  4 2021 Wang Jun <jgwang@suse.com>
- Update to version 3.0.1
  * Fixed JavaDoc issue for JDK 8
  * maven-dependency-tree removes optional flag from
    managed dependencies
  * Change characters used to diplay trees to make
    relationships clearer
  * Pass source+target to m-invoker-p, easiest way to override
    default values of maven-compiler-plugin
  * Upgrade org.codehaus.plexus:plexus-component-metadata to 1.7.1
* Mon Mar 25 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of maven-dependency-tree 3.0
- Generate and customize the ant build.xml file
